@@ -2,7 +2,7 @@ import logging
 
 import numpy as np
 
-from ...data_classes import Detections
+from ...data_classes import ImageMetadata
 from ...detector.detector_logic import DetectorLogic
 from ..test_helper import get_dummy_detections
 
@@ -12,11 +12,11 @@ class TestingDetectorLogic(DetectorLogic):
 
     def __init__(self) -> None:
         super().__init__('mocked')
-        self.det_to_return: Detections = get_dummy_detections()
+        self.det_to_return: ImageMetadata = get_dummy_detections()
 
     def init(self) -> None:
         pass
 
-    def evaluate(self, image: np.ndarray) -> Detections:
+    def evaluate(self, image: np.ndarray) -> ImageMetadata:
         logging.info('evaluating')
         return self.det_to_return
